@@ -10,15 +10,11 @@ logger = getLogger(__name__)
 
 
 class CannyFilter(Filter):
-    def __init__(self, sigma: float = 0.33, debug: bool = False) -> None:
-        self.sigma = sigma
+    def __init__(self, debug: bool = False) -> None:
         self.debug = debug
 
     def eval(self, image: np.ndarray) -> np.ndarray:
         logger.debug("Applying 'CannyFilter'...")
-        median = np.median(image)
-        lower = int(max(0, (1.0 - self.sigma) * median))
-        upper = int(min(255, (1.0 + self.sigma) * median))
-        edges_detected_image = cv2.Canny(image, lower, upper)
+        edges_detected_image = cv2.Canny(image, 0, 200)
         debug_show(edges_detected_image, debug=self.debug)
         return edges_detected_image
